@@ -131,10 +131,12 @@ def setup_actions_with_args(
                 context = options.get('context', None)
                 if context:
                     context = context.split(',')
+                reverse = options.get('reverse', False)
                 config.actions.append(AssignIdConfig(
                     target = target,
                     primary = [source],
                     context = context,
+                    reverse = reverse,
                 ))
                 continue
             if action_name == 'filter-empty':
@@ -488,7 +490,8 @@ def assign_format(
             params[key] = f'__{key}__undefined__'
         except:
             #ic(params)
-            ic(params.keys())
+            #ic(params.keys())
+            ic(row.flat)
             raise
     set_row_staging_value(row, config.target, formatted)
     return row
